==> jc-1.4.0.tar.gz: polyglot/visit/InitChecker__24ClassBodyInfo.h <==
// public class polyglot.visit.InitChecker$ClassBodyInfo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 905872af2f137011 polyglot_visit_InitChecker__24ClassBodyInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_InitChecker__24ClassBodyInfo_H_
#define _JC_polyglot_visit_InitChecker__24ClassBodyInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_ast_CodeDecl$object;
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$object;

// Typedefs
typedef struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_refs	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_refs;
typedef struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_nonrefs	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$refs	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$refs;
typedef struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$nonrefs	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$object	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$object;

typedef const struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vmethods	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$vmethods;
typedef const struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtable	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtable;
typedef const struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtype	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtype;

// Constructors
extern void _jc_polyglot_visit_InitChecker__24ClassBodyInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$object *);

// Virtual methods structure
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vmethods {
};

// Vtable
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$vmethods	polyglot_visit_InitChecker__24ClassBodyInfo;
};

// Vtype
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtype {
	_jc_type			type;
	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_refs {
	struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$object	*outer;
	struct _jc_object	*currCodeDecl;
	struct _jc_object	*currClassFinalFieldInitCounts;
	struct _jc_object	*allConstructors;
	struct _jc_object	*constructorCalls;
	struct _jc_object	*fieldsConstructorInitializes;
	struct _jc_object	*outerLocalsUsed;
	struct _jc_object	*localsUsedInClassBodies;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$refs {
    _jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_refs	polyglot_visit_InitChecker__24ClassBodyInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_nonrefs	polyglot_visit_InitChecker__24ClassBodyInfo;
};

// Object instance structure
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$object {
	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtype	*vtype;
	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtype _jc_polyglot_visit_InitChecker__24ClassBodyInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_InitChecker__24ClassBodyInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_InitChecker__24ClassBodyInfo$class_object;

#endif	/* _JC_polyglot_visit_InitChecker__24ClassBodyInfo_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/InitChecker__24ClassBodyInfo.h <==
// public class polyglot.visit.InitChecker$ClassBodyInfo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 905872af2f137011 polyglot_visit_InitChecker__24ClassBodyInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_InitChecker__24ClassBodyInfo_H_
#define _JC_polyglot_visit_InitChecker__24ClassBodyInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_ast_CodeDecl$object;
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$object;

// Typedefs
typedef struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_refs	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_refs;
typedef struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_nonrefs	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$refs	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$refs;
typedef struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$nonrefs	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$object	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$object;

typedef const struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vmethods	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$vmethods;
typedef const struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtable	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtable;
typedef const struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtype	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtype;

// Constructors
extern void _jc_polyglot_visit_InitChecker__24ClassBodyInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vmethods {
};

// Vtable
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$vmethods	polyglot_visit_InitChecker__24ClassBodyInfo;
};

// Vtype
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtype {
	_jc_type			type;
	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_refs {
	struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$object	*outer;
	struct _jc_object	*currCodeDecl;
	struct _jc_object	*currClassFinalFieldInitCounts;
	struct _jc_object	*allConstructors;
	struct _jc_object	*constructorCalls;
	struct _jc_object	*fieldsConstructorInitializes;
	struct _jc_object	*outerLocalsUsed;
	struct _jc_object	*localsUsedInClassBodies;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$refs {
    _jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_refs	polyglot_visit_InitChecker__24ClassBodyInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_InitChecker__24ClassBodyInfo$sub_nonrefs	polyglot_visit_InitChecker__24ClassBodyInfo;
};

// Object instance structure
struct _jc_polyglot_visit_InitChecker__24ClassBodyInfo$object {
	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtype	*vtype;
	_jc_polyglot_visit_InitChecker__24ClassBodyInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_InitChecker__24ClassBodyInfo$vtype _jc_polyglot_visit_InitChecker__24ClassBodyInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_InitChecker__24ClassBodyInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_InitChecker__24ClassBodyInfo$class_object;

#endif	/* _JC_polyglot_visit_InitChecker__24ClassBodyInfo_H_ */
